@@ -1,73 +1,17 @@
-
 use strict;
 use warnings;
-
 package Games::Bowling::Scorecard::AsText;
+{
+  $Games::Bowling::Scorecard::AsText::VERSION = '0.104';
+}
+# ABSTRACT: format a bowling scorecard as text
 
-=head1 NAME
-
-Games::Bowling::Scorecard::AsText - format a bowling scorecard as text
-
-=head1 VERSION
-
-version 0.103
-
-=cut
-
-our $VERSION = '0.103';
-
-=head1 SYNOPSIS
-
-  use Games::Bowling::Scorecard;
-
-  my $card = Games::Bowling::Scorecard->new;
-
-  $card->record(6,1);  # slow start
-  $card->record(7,2);  # getting better
-  $card->record(10);   # strike!
-  $card->record(9,1);  # picked up a spare
-  $card->record(10) for 1 .. 3; # turkey!
-  $card->record(0,0);  # clearly distracted by something
-  $card->record(8,2);  # amazingly picked up 7-10 split
-  $card->record(10, 9, 1); # pick up a bonus spare
-
-  print Games::Bowling::Scorecard::AsText->card_as_text($card);
-
-The above outputs:
-
-  +-----+-----+-----+-----+-----+-----+-----+-----+-----+-------+
-  | 6 1 | 7 2 | X   | 9 / | X   | X   | X   | - - | 8 / | X 9 / |
-  |   7 |  16 |  36 |  56 |  86 | 106 | 116 | 116 | 136 |   156 |
-
-=head1 WARNING
-
-This module's interface is almost certain to change, whenever the author gets
-around to it.
-
-=head1 DESCRIPTION
-
-So, you've written a bowling record-keeper and now you want to print out
-scorecards to your dynamic Gopher site.  Games::Bowling::Scorecard has taken
-care of the scoring, but now you need to worry about all those slashes and
-dashes and X's
-
-=head1 METHODS
-
-=head2 card_as_text
-
-  my $text = Games::Bowling::Scorecard::AsText->card_as_text($card);
-
-Given a scorecard, this method returns a three-line text version of the card,
-using standard notation.  A total is kept only through the last non-pending
-frame.
-
-=cut
 
 use Carp ();
 
 sub card_as_text {
   my ($self, $card) = @_;
-  
+
   my $hdr = '+-----+-----+-----+-----+-----+-----+-----+-----+-----+-------+';
   my $balls  = '';
   my $scores = '';
@@ -143,24 +87,74 @@ sub _three_balls {
   }
 }
 
+300;
+
+__END__
+
+=pod
+
+=head1 NAME
+
+Games::Bowling::Scorecard::AsText - format a bowling scorecard as text
+
+=head1 VERSION
+
+version 0.104
+
+=head1 SYNOPSIS
+
+  use Games::Bowling::Scorecard;
+
+  my $card = Games::Bowling::Scorecard->new;
+
+  $card->record(6,1);  # slow start
+  $card->record(7,2);  # getting better
+  $card->record(10);   # strike!
+  $card->record(9,1);  # picked up a spare
+  $card->record(10) for 1 .. 3; # turkey!
+  $card->record(0,0);  # clearly distracted by something
+  $card->record(8,2);  # amazingly picked up 7-10 split
+  $card->record(10, 9, 1); # pick up a bonus spare
+
+  print Games::Bowling::Scorecard::AsText->card_as_text($card);
+
+The above outputs:
+
+  +-----+-----+-----+-----+-----+-----+-----+-----+-----+-------+
+  | 6 1 | 7 2 | X   | 9 / | X   | X   | X   | - - | 8 / | X 9 / |
+  |   7 |  16 |  36 |  56 |  86 | 106 | 116 | 116 | 136 |   156 |
+
+=head1 DESCRIPTION
+
+So, you've written a bowling record-keeper and now you want to print out
+scorecards to your dynamic Gopher site.  Games::Bowling::Scorecard has taken
+care of the scoring, but now you need to worry about all those slashes and
+dashes and X's
+
+=head1 METHODS
+
+=head2 card_as_text
+
+  my $text = Games::Bowling::Scorecard::AsText->card_as_text($card);
+
+Given a scorecard, this method returns a three-line text version of the card,
+using standard notation.  A total is kept only through the last non-pending
+frame.
+
+=head1 WARNING
+
+This module's interface is almost certain to change, whenever the author gets
+around to it.
+
 =head1 AUTHOR
 
-Ricardo SIGNES, C<< <rjbs at cpan.org> >>
+Ricardo SIGNES <rjbs@cpan.org>
 
-=head1 BUGS
+=head1 COPYRIGHT AND LICENSE
 
-Please report any bugs or feature requests to the web interface at
-L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Games-Bowling-Scorecard>.  I
-will be notified, and then you'll automatically be notified of progress on your
-bug as I make changes.
+This software is copyright (c) 2013 by Ricardo SIGNES.
 
-=head1 COPYRIGHT & LICENSE
-
-Copyright 2007 Ricardo SIGNES, all rights reserved.
-
-This program is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-300;
